@@ -25,21 +25,32 @@ class Bossman:
 
   def get_resources(self, rev: str = "HEAD", glob: str = "*") -> list:
     resources = self.resource_manager.get_resources(self.repo, rev)
-    return list(filter(lambda resource: fnmatch(resource.path, glob), resources))
+    return list(sorted(filter(lambda resource: fnmatch(resource.path, glob), resources)))
 
   def get_resource_status(self, resource: ResourceABC) -> ResourceStatus:
     resource_type = self.resource_manager.get_resource_type(resource.path)
-    last_rev = self.repo.get_last_revision(resource.paths)
-    remote_rev = resource_type.get_remote_rev(resource)
-    missing_revisions = self.repo.get_revisions(remote_rev.local_rev, last_rev.id, resource.paths)
+    # latest commit affecting this resource
+    last_revision = self.repo.get_last_revision(resource.paths)
+    # get info from the plugin about that revision (remote version number?)
+    last_revision_details = resource_type.get_revision_details(resource, last_revision.id)
+    # get latest applied revision id and plugin specific info from remote history
+    last_applied_revision_details = resource_type.get_revision_details(resource)
+    # get revision from local repo
+    last_applied_revision = self.repo.get_revision(last_applied_revision_details.id, resource.paths) if last_applied_revision_details.id else None
+    missing_revisions = self.repo.get_revisions(last_applied_revision_details.id, last_revision.id, resource.paths)
     dirty = resource_type.is_dirty(resource)
     return ResourceStatus(
-      local_rev=last_rev.id,
-      remote_rev=remote_rev,
+      last_revision=last_revision,
+      last_revision_details=last_revision_details,
+      last_applied_revision=last_applied_revision,
+      last_applied_revision_details=last_applied_revision_details,
       dirty=dirty,
       missing_revisions=list(reversed(missing_revisions))
     )
 
+  def get_revision(self, rev: str = None, resources: list = None) -> str:
+    return self.repo.get_revision(rev, (p for r in resources for p in r.paths))
+
   def get_revisions(self, since_rev: str = None, until_rev: str = "HEAD", resources: list = None) -> str:
     return self.repo.get_revisions(since_rev, until_rev, resources)
 
